@@ -1,6 +1,14 @@
 use crate::errors::CliError;
 use std::fs::write;
-use std::io::{self, stdin, stdout, Write};
+use std::io::{self, stdin, stdout, Read, Write};
+
+pub fn read_stdin() -> anyhow::Result<String> {
+    let mut buffer = String::new();
+    io::stdin()
+        .read_to_string(&mut buffer)
+        .map_err(|_| CliError::ReadStdinError)?;
+    Ok(buffer)
+}
 
 pub fn read_input() -> io::Result<String> {
     stdout().flush()?;
